# nzshm-common

A pure python library of shared objects used in nzshm projects

[![pypi](https://img.shields.io/pypi/v/nzshm-common.svg)](https://pypi.org/project/nzshm-common/)
[![python](https://img.shields.io/pypi/pyversions/nzshm-common.svg)](https://pypi.org/project/nzshm-common/)
[![Build Status](https://github.com/GNS-Science/nzshm-common-py/actions/workflows/dev.yml/badge.svg)](https://github.com/GNS-Science/nzshm-common-py/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/GNS-Science/nzshm-common-py/branch/main/graphs/badge.svg)](https://codecov.io/github/GNS-Science/nzshm-common-py)


* Documentation: <https://GNS-Science.github.io/nzshm-common-py>
* GitHub: <https://github.com/GNS-Science/nzshm-common-py>
* PyPI: <https://pypi.org/project/nzshm-common/>
* Free software: GPL-3.0-only

## Installation

```
pip install nzshm-common
```

## Use

```
>>> from nzshm_common.location import location
>>> dir(location)
['LOCATIONS', 'LOCATION_LISTS', '__builtins__', '__cached__', '__doc__', '__file__', '__loader__', '__name__', '__package__', '__spec__', 'location_by_id']
>>>
```
